@@ -48,6 +48,12 @@ cbc_cts_encrypt (void *ctx,
   unsigned restbytes = (length % block_size) == 0 ?
     block_size : length % block_size;
 
+  if (length > block_size)
+    {
+      if ((length % block_size) == 0)
+	nblocks--;
+    }
+
   for (; nblocks; nblocks--, src += block_size, dst += block_size)
     {
       memxor (iv, src, block_size);
@@ -63,6 +69,7 @@ cbc_cts_encrypt (void *ctx,
       memset (dst + restbytes, 0, block_size - restbytes);
       memxor (iv, dst, block_size);
       f (ctx, block_size, dst, iv);
+      memcpy (iv, dst + restbytes, block_size);
     }
 }
 
@@ -97,6 +104,7 @@ cbc_cts_decrypt (void *ctx,
 
   if (length > block_size)
     {
+      memcpy (tmpiv, iv, block_size);
       memcpy (iv, src + block_size, restbytes);
       f (ctx, block_size, dst, src);
       memxor (dst, iv, restbytes);
@@ -104,5 +112,9 @@ cbc_cts_decrypt (void *ctx,
       memcpy (iv + restbytes, dst + restbytes, block_size - restbytes);
       f (ctx, block_size, dst, iv);
       memxor (dst, tmpiv, block_size);
+      if ((length % block_size) == 0)
+	memcpy (iv, src + block_size, block_size);
+      else
+	memcpy (iv, src + restbytes, block_size);
     }
 }
