@@ -19,22 +19,29 @@
  *
  */
 
-#include "internal.h"
+#include "info.h"
+
+/* Get "file" database prototypes. */
+#include "file.h"
 
 static _Shisa_backend _shisa_backends[] = {
-  { "file",
-    shisa_file_init,
-    shisa_file_enumerate_realms,
-    shisa_file_enumerate_principals,
-    shisa_file_principal_find,
-    shisa_file_principal_update,
-    shisa_file_principal_add,
-    shisa_file_principal_remove,
-    shisa_file_enumerate_keys,
-    shisa_file_key_add,
-    shisa_file_done }
+  {"file",
+   shisa_file_init,
+   shisa_file_done,
+   shisa_file_enumerate_realms,
+   shisa_file_enumerate_principals,
+   shisa_file_principal_find,
+   shisa_file_principal_update,
+   shisa_file_principal_add,
+   shisa_file_principal_remove,
+   shisa_file_keys_find,
+   shisa_file_key_add,
+   shisa_file_key_update,
+   shisa_file_key_remove}
 };
 
+/* Return structure with function pointers implementing a Shisa
+   backend, given a name (e.g., "file"). */
 _Shisa_backend *
 _shisa_find_backend (const char *name)
 {
