@@ -1,4 +1,4 @@
-/* aprep.c	AP-REP functions
+/* aprep.c --- AP-REP functions.
  * Copyright (C) 2002, 2003  Simon Josefsson
  *
  * This file is part of Shishi.
@@ -21,6 +21,9 @@
 
 #include "internal.h"
 
+/* Get _shishi_print_armored_data, etc. */
+#include "diskio.h"
+
 #define SHISHI_APREP_DEFAULT_PVNO "5"
 #define SHISHI_APREP_DEFAULT_PVNO_LEN 0
 #define SHISHI_APREP_DEFAULT_MSG_TYPE      "15"	/* KRB_AP_REP */
