@@ -1,4 +1,4 @@
-/* apreq.c	AP-REQ functions
+/* apreq.c --- AP-REQ functions.
  * Copyright (C) 2002, 2003  Simon Josefsson
  *
  * This file is part of Shishi.
@@ -21,6 +21,9 @@
 
 #include "internal.h"
 
+/* Get _shishi_print_armored_data, etc. */
+#include "diskio.h"
+
 #define SHISHI_APREQ_DEFAULT_PVNO "5"
 #define SHISHI_APREQ_DEFAULT_PVNO_LEN 0
 #define SHISHI_APREQ_DEFAULT_MSG_TYPE      "14"	/* KRB_AP_REQ */
@@ -682,7 +685,7 @@ shishi_apreq_get_ticket (Shishi * handle,
 
   /* there's GOT to be an easier way to do this */
 
-  *ticket = shishi_asn1_ticket (handle);
+  *ticket = shishi_ticket (handle);
   if (!*ticket)
     return SHISHI_ASN1_ERROR;
 
