@@ -1,4 +1,4 @@
-/* authenticator.c	functions for authenticators
+/* authenticator.c --- Functions for authenticators.
  * Copyright (C) 2002, 2003  Simon Josefsson
  *
  * This file is part of Shishi.
@@ -21,6 +21,9 @@
 
 #include "internal.h"
 
+/* Get _shishi_print_armored_data, etc. */
+#include "diskio.h"
+
 /**
  * shishi_authenticator:
  * @handle: shishi handle as allocated by shishi_init().
@@ -857,7 +860,7 @@ shishi_authenticator_add_random_subkey (Shishi * handle,
 
   n = shishi_cfg_clientkdcetype (handle, &etypes);
   if (n <= 0)
-    return SHISHI_TICKET_BAD_KEYTYPE; /* XXX */
+    return SHISHI_TICKET_BAD_KEYTYPE;	/* XXX */
 
   res = shishi_authenticator_add_random_subkey_etype (handle, authenticator,
 						      etypes[0]);
