@@ -1,4 +1,4 @@
-/* kdcrep.c	Key distribution (AS/TGS) Reply functions
+/* kdcrep.c --- Key distribution (AS/TGS) Reply functions.
  * Copyright (C) 2002, 2003  Simon Josefsson
  *
  * This file is part of Shishi.
@@ -21,6 +21,9 @@
 
 #include "internal.h"
 
+/* Get _shishi_print_armored_data, etc. */
+#include "diskio.h"
+
 #define SHISHI_KDCREP_DEFAULT_PVNO      "5"
 #define SHISHI_KDCREP_DEFAULT_PVNO_LEN  0
 #define SHISHI_AS_REP_DEFAULT_MSG_TYPE      "11"
@@ -385,7 +388,7 @@ shishi_kdcrep_get_ticket (Shishi * handle,
 
   /* there's GOT to be an easier way to do this */
 
-  *ticket = shishi_asn1_ticket (handle);
+  *ticket = shishi_ticket (handle);
   if (!*ticket)
     return SHISHI_ASN1_ERROR;
 
