@@ -1,4 +1,4 @@
-/* safe.c	Application data integrity protection.
+/* safe.c --- Application data integrity protection.
  * Copyright (C) 2002, 2003  Simon Josefsson
  *
  * This file is part of Shishi.
@@ -21,6 +21,9 @@
 
 #include "internal.h"
 
+/* Get _shishi_print_armored_data, etc. */
+#include "diskio.h"
+
 struct Shishi_safe
 {
   Shishi *handle;
