@@ -87,10 +87,6 @@ shishi_tgs (Shishi * handle, Shishi_tgs ** tgs)
   if (res != SHISHI_OK)
     return res;
 
-  res = shishi_tkt_flags_set (ltgs->tkt, SHISHI_TICKETFLAGS_INITIAL);
-  if (res != SHISHI_OK)
-    return res;
-
   return SHISHI_OK;
 }
 
@@ -254,6 +250,10 @@ shishi_tgs_req_process (Shishi_tgs * tgs)
 
   shishi_ap_req_set (tgs->ap, apreq);
 
+  rc = shishi_ap_req_decode (tgs->ap);
+  if (rc != SHISHI_OK)
+    return rc;
+
   return SHISHI_OK;
 }
 
@@ -498,7 +498,7 @@ shishi_tgs_krberror_der (Shishi_tgs * tgs, char **out, size_t * outlen)
 {
   int rc;
 
-  rc = shishi_new_a2d (tgs->handle, tgs->krberror, out, outlen);
+  rc = shishi_krberror_der (tgs->handle, tgs->krberror, out, outlen);
   if (rc != SHISHI_OK)
     return rc;
 
