@@ -1,4 +1,4 @@
-/* util.c	auxilliary help functions.
+/* utils.c --- Auxilliary help functions.
  * Copyright (C) 2002, 2003  Simon Josefsson
  *
  * This file is part of Shishi.
@@ -21,6 +21,9 @@
 
 #include "internal.h"
 
+/* Get prototypes. */
+#include "utils.h"
+
 void
 _shishi_escapeprint (const char *str, int len)
 {
