@@ -45,11 +45,11 @@ gnutls_anon_server_credentials x509cred;
 static void
 kdc_listen (void)
 {
-  struct listenspec *ls, **last;
+  struct listenspec *ls, *tmp;
   int maxfd = 0;
   int yes;
 
-  for (ls = listenspec, last = NULL; ls; last = &ls->next, ls = ls->next)
+  for (ls = listenspec; ls; ls = ls->next)
     {
       if (!arg.quiet_flag)
 	printf ("Listening on %s...\n", ls->str);
@@ -91,12 +91,14 @@ kdc_listen (void)
     errorclose:
       close (ls->sockfd);
     error:
+      tmp = ls->next;
+      if (listenspec == ls)
+	listenspec = tmp;
       free (ls->str);
-      if (last)
-	*last = ls->next;
-      else
-	listenspec = ls->next;
       free (ls);
+      ls = tmp;
+      if (!ls)
+	break;
     }
 
   if (maxfd == 0)
@@ -116,8 +118,9 @@ kdc_unlisten (void)
   for (ls = listenspec; ls; ls = ls->next)
     {
       if (!ls->listening)
-	error (0, 0, "Unclosed outstanding connection to %s on socket %d?!",
-	       ls->str, ls->sockfd);
+	syslog (LOG_NOTICE,
+		"Closing outstanding connection to %s on socket %d",
+		ls->str, ls->sockfd);
 
       if (ls->sockfd)
 	{
@@ -125,8 +128,8 @@ kdc_unlisten (void)
 	    printf ("Closing %s...\n", ls->str);
 	  rc = close (ls->sockfd);
 	  if (rc != 0)
-	    error (0, errno, "Could not close %s on socket %d",
-		   ls->str, ls->sockfd);
+	    syslog (LOG_ERR, "Could not close %s on socket %d: %s (%d)",
+		    ls->str, ls->sockfd, strerror (errno), errno);
 	}
 
       if (ls->str)
@@ -322,8 +325,6 @@ doit (void)
 
   kdc_loop ();
 
-  closelog ();
-
   kdc_unlisten ();
 
 #ifdef USE_STARTTLS
